@@ -1,15 +1,16 @@
-from fedbase.utils.data_loader import data_process
+from fedbase.utils.data_loader import data_process, log
 from fedbase.nodes.node import node
 from fedbase.server.server import server_class
 import torch
 from torch.utils.data import DataLoader
 import torch.optim as optim
 from fedbase.model.model import CNNCifar, CNNMnist
+import os
 
 
-def cfl(dir, dataset, batch_size, K, num_nodes, model, objective, optimizer, global_rounds, local_epochs, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')):
-    dt = data_process(dir, dataset)
-    train_splited,test_splited = dt.split_dataset(num_nodes, 2, method='class')
+def cfl(dataset, batch_size, K, num_nodes, model, objective, optimizer, global_rounds, local_epochs, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu'), **split):
+    dt = data_process(dataset)
+    train_splited,test_splited = dt.split_dataset(num_nodes, split['split_para'], split['split_method'])
 
     server = server_class()
     server.assign_model(model(), device)
@@ -39,7 +40,7 @@ def cfl(dir, dataset, batch_size, K, num_nodes, model, objective, optimizer, glo
         print('-------------------Global round %d start-------------------' % (i))
         # single-processing!
         for j in range(num_nodes):
-            nodes[j].local_update(local_epochs, device)
+            nodes[j].local_update_steps(local_epochs, device)
             nodes[j].local_test(device)
         # server clustering
         server.weighted_clustering(nodes, list(range(num_nodes)), K)
