@@ -1,14 +1,14 @@
-from fedbase.utils.data_loader import data_process
+from fedbase.utils.data_loader import data_process, log
 from fedbase.nodes.node import node
 from fedbase.server.server import server_class
 import torch
 from torch.utils.data import DataLoader
 import torch.optim as optim
+import os
 
-
-def ditto(dir, dataset, batch_size, num_nodes, model, objective, optimizer, global_rounds, local_epochs, reg_lam, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu')):
-    dt = data_process(dir, dataset)
-    train_splited,test_splited = dt.split_dataset(num_nodes, 2, method='class')
+def ditto(dataset, batch_size, num_nodes, model, objective, optimizer, global_rounds, local_epochs, reg_lam, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu'), **split):
+    dt = data_process(dataset)
+    train_splited,test_splited = dt.split_dataset(num_nodes, split['split_para'], split['split_method'])
 
     server = server_class()
     server.assign_model(model(), device)
@@ -38,7 +38,7 @@ def ditto(dir, dataset, batch_size, num_nodes, model, objective, optimizer, glob
         print('-------------------Global round %d start-------------------' % (i))
         # single-processing!
         for j in range(num_nodes):
-            nodes[j].ditto_local_update(local_epochs, device, server, reg_lam)
+            nodes[j].local_update_ditto(local_epochs, device, server, reg_lam)
             nodes[j].local_test(device)
         # server aggregation and distribution
         server.aggregate(nodes, list(range(num_nodes)), device)
